@@ -24,7 +24,7 @@ from ..conf.utils_conf import print_precision, check_array
 
 
 def cube_inject_companions(array, psf_template, angle_list, flevel, plsc,
-                           rad_dists, n_branches=1, theta=0, imlib='opencv',
+                           rad_dists, n_branches=1, theta=0, imlib='vip-fft',
                            interpolation='lanczos4', transmission=None, 
                            full_output=False, verbose=True):
     """ Injects fake companions in branches, at given radial distances.
@@ -146,7 +146,9 @@ def cube_inject_companions(array, psf_template, angle_list, flevel, plsc,
         size_fc = psf_template.shape[1]
         nframes = array.shape[0]
 
-        w = int(np.ceil(size_fc/2)) - 1
+        w = int(np.ceil(size_fc/2))
+        if size_fc%2: # new convention
+            w -= 1
         sty = int(ceny) - w
         sty = int(cenx) - w
 
@@ -394,7 +396,7 @@ def generate_cube_copies_with_injections(array, psf_template, angle_list, plsc,
 
 
 def frame_inject_companion(array, array_fc, pos_y, pos_x, flux,
-                           imlib='opencv', interpolation='lanczos4'):
+                           imlib='vip-fft', interpolation='lanczos4'):
     """ Injects a fake companion in a single frame (it could be a single
      multi-wavelength frame) at given coordinates.
     """
@@ -407,8 +409,9 @@ def frame_inject_companion(array, array_fc, pos_y, pos_x, flux,
         cenx = int(cenx)
         fc_fr = np.zeros_like(array)
         w = int(np.floor(size_fc/2.))
+        odd = size_fc%2
         # fake companion in the center of a zeros frame
-        fc_fr[ceny-w:ceny+w+1, cenx-w:cenx+w+1] = array_fc
+        fc_fr[ceny-w:ceny+w+odd, cenx-w:cenx+w+odd] = array_fc
         array_out = array + frame_shift(fc_fr, pos_y-ceny, pos_x-cenx, imlib,
                                         interpolation) * flux
 
@@ -419,8 +422,9 @@ def frame_inject_companion(array, array_fc, pos_y, pos_x, flux,
         cenx = int(cenx)
         fc_fr = np.zeros_like(array)
         w = int(np.floor(size_fc/2.))
+        odd = size_fc%2
         # fake companion in the center of a zeros frame
-        fc_fr[:, ceny-w:ceny+w+1, cenx-w:cenx+w+1] = array_fc
+        fc_fr[:, ceny-w:ceny+w+odd, cenx-w:cenx+w+odd] = array_fc
         array_out = array + cube_shift(fc_fr, pos_y - ceny, pos_x - cenx,
                                        imlib, interpolation) * flux
 
@@ -470,7 +474,7 @@ def collapse_psf_cube(array, size, fwhm=4, verbose=True, collapse='mean'):
 
 
 def normalize_psf(array, fwhm='fit', size=None, threshold=None, mask_core=None,
-                  model='gauss', imlib='opencv', interpolation='lanczos4',
+                  model='gauss', imlib='vip-fft', interpolation='lanczos4',
                   force_odd=True, full_output=False, verbose=True, debug=False):
     """ Normalizes a PSF (2d or 3d array), to have the flux in a 1xFWHM
     aperture equal to one. It also allows to crop the array and center the PSF
