@@ -1,11 +1,13 @@
 #! /usr/bin/env python
 
 """
-Implementation of the STIM map from [PAI18]
-.. [PAI18]
-   | Paret et al, 1018
-   | **STIM map: detection map for exoplanets imaging beyond asymptotic Gaussian residual speckle noise**
-   | *submitted in Monthly Notices of the Royal Astronomical Society*
+Implementation of the STIM map from [PAI19]
+
+.. [PAI19]
+   | Pairet et al, 2019
+   | STIM map: detection map for exoplanets imaging beyond asymptotic Gaussian residual speckle noise**
+   | *MNRAS, 487, 2262*
+   | `doi:10.1093/mnras/stz1350 <http://doi.org/10.1093/mnras/stz1350>`_
 """
 __author__ = 'Benoit Pairet'
 __all__ = ['compute_stim_map',
@@ -38,8 +40,7 @@ def compute_stim_map(cube_der):
     return get_circle(detection_map, int(np.round(n/2.)))
 
 
-def compute_inverse_stim_map(cube, angle_list, imlib='opencv',
-                             interpolation='lanczos4'):
+def compute_inverse_stim_map(cube, angle_list, **rot_options):
     """ Computes the inverse STIM detection map.
 
     Parameters
@@ -49,10 +50,11 @@ def compute_inverse_stim_map(cube, angle_list, imlib='opencv',
         from ``vip_hci.pca.pca``.
     angle_list : numpy ndarray, 1d
         Corresponding parallactic angle for each frame.  
-    imlib: str, opt
-        See description of vip_hci.preproc.frame_derotate()
-    interpolation: str, opt
-        See description of vip_hci.preproc.frame_derotate()
+    rot_options: dictionary, optional
+        Dictionary with optional keyword values for "nproc", "imlib", 
+        "interpolation, "border_mode", "mask_val",  "edge_blend", 
+        "interp_zeros", "ker" (see documentation of 
+        ``vip_hci.preproc.frame_rotate``)
         
     Returns
     -------
@@ -60,7 +62,6 @@ def compute_inverse_stim_map(cube, angle_list, imlib='opencv',
         Inverse STIM detection map.
     """
     t, n, _ = cube.shape
-    cube_inv_der = cube_derotate(cube, -angle_list, imlib=imlib, 
-                                 interpolation=interpolation)
+    cube_inv_der = cube_derotate(cube, -angle_list, **rot_options)
     inverse_stim_map = compute_stim_map(cube_inv_der)
     return inverse_stim_map
\ No newline at end of file
