@@ -23,7 +23,7 @@ __all__ = ['firstguess']
 def firstguess_from_coord(planet, center, cube, angs, PLSC, psf, fwhm,
                           annulus_width, aperture_radius, ncomp, cube_ref=None,
                           svd_mode='lapack', scaling=None, fmerit='sum',
-                          imlib='opencv', interpolation='lanczos4',
+                          imlib='vip-fft', interpolation='lanczos4',
                           collapse='median', algo=pca_annulus, delta_rot=1, 
                           algo_options={}, f_range=None, transmission=None, 
                           mu_sigma=None, weights=None, plot=False, 
@@ -167,7 +167,7 @@ def firstguess_from_coord(planet, center, cube, angs, PLSC, psf, fwhm,
 
 def firstguess_simplex(p, cube, angs, psf, plsc, ncomp, fwhm, annulus_width, 
                        aperture_radius, cube_ref=None, svd_mode='lapack', 
-                       scaling=None, fmerit='sum', imlib='opencv',
+                       scaling=None, fmerit='sum', imlib='vip-fft',
                        interpolation='lanczos4', collapse='median', 
                        algo=pca_annulus, delta_rot=1, algo_options={}, 
                        p_ini=None, transmission=None, mu_sigma=None, 
@@ -288,7 +288,7 @@ def firstguess_simplex(p, cube, angs, psf, plsc, ncomp, fwhm, annulus_width,
 
 def firstguess(cube, angs, psfn, ncomp, plsc, planets_xy_coord, fwhm=4, 
                annulus_width=4, aperture_radius=1, cube_ref=None, 
-               svd_mode='lapack', scaling=None, fmerit='sum', imlib='opencv',
+               svd_mode='lapack', scaling=None, fmerit='sum', imlib='vip-fft',
                interpolation='lanczos4', collapse='median', algo=pca_annulus,
                delta_rot=1, p_ini=None, f_range=None, transmission=None, 
                mu_sigma=None, wedge=None, weights=None, force_rPA= False, 
