@@ -24,24 +24,14 @@ except ImportError:
     msg = "Opencv python bindings are missing."
     warnings.warn(msg, ImportWarning)
     no_opencv = True
-try:
-    from numba import njit
-    no_numba = False
-except ImportError:
-    msg = "Numba python bindings are missing. "
-    msg+= "Consider installing Numba for faster fft-based image rotations."
-    warnings.warn(msg, ImportWarning)
-    no_numba = True
 from skimage.transform import rotate
 from multiprocessing import cpu_count
 from .cosmetics import frame_pad
 from ..conf.utils_conf import pool_map, iterable
-from ..var import frame_center, frame_filter_lowpass  
-    
-data_array = None  # holds the (implicitly mem-shared) data array
+from ..var import frame_center, frame_filter_lowpass
 
 
-def frame_rotate(array, angle, imlib='opencv', interpolation='lanczos4',
+def frame_rotate(array, angle, imlib='vip-fft', interpolation='lanczos4',
                  cxy=None, border_mode='constant', mask_val=np.nan, 
                  edge_blend=None, interp_zeros=False, ker=1):
     """ Rotates a frame or 2D array.
@@ -156,9 +146,13 @@ def frame_rotate(array, angle, imlib='opencv', interpolation='lanczos4',
                                           size=(new_y,new_x))
         cy, cx = frame_center(array_prep)
         y0_p = int(cy-cy_ori)
-        y1_p = int(cy+cy_ori+1)
+        y1_p = int(cy+cy_ori)
+        if new_y%2:
+            y1_p+=1
         x0_p = int(cx-cx_ori)
-        x1_p = int(cx+cx_ori+1)
+        x1_p = int(cx+cx_ori)
+        if new_x%2:
+            x1_p+=1
         if interp_zeros:
             array_prep[y0_p:y1_p,x0_p:x1_p] = array_nan.copy()
             array_prep1[y0_p:y1_p,x0_p:x1_p] = array_nan.copy()
@@ -203,7 +197,7 @@ def frame_rotate(array, angle, imlib='opencv', interpolation='lanczos4',
             y0 = y0_p
             y1 = y1_p
             x0 = x0_p
-            x1 = x1_p            
+            x1 = x1_p
     else:
         array_prep = array.copy()
 
@@ -214,18 +208,15 @@ def frame_rotate(array, angle, imlib='opencv', interpolation='lanczos4',
     
     if cxy is None:
         cy, cx = frame_center(array_prep)
-    elif edge_blend:
-        cx_rot, cy_rot = cxy
-        cx += cx_rot-cx_ori
-        cy += cy_rot-cy_ori
-        if imlib=='fft' and (cy, cx) != frame_center(array_prep):
-            msg = "Case not yet implemented. Center image manually first"
-            raise ValueError(msg)
+    elif imlib!='opencv':
+        msg = "Only 'opencv' imlib allows for different center to be provided"
+        raise ValueError(msg)
     else:
         cx, cy = cxy
 
     if imlib == 'vip-fft':
         array_out = rotate_fft(array_prep, angle)
+        
     elif imlib == 'skimage':
         if interpolation == 'nearneig':
             order = 0
@@ -302,9 +293,9 @@ def frame_rotate(array, angle, imlib='opencv', interpolation='lanczos4',
     return array_out
     
     
-def cube_derotate(array, angle_list, imlib='opencv', interpolation='lanczos4',
+def cube_derotate(array, angle_list, imlib='vip-fft', interpolation='lanczos4',
                   cxy=None, nproc=1, border_mode='constant', mask_val=np.nan,
-                  edge_blend=None, interp_zeros=False):
+                  edge_blend=None, interp_zeros=False, ker=1):
     """ Rotates an cube (3d array or image sequence) providing a vector or
     corresponding angles. Serves for rotating an ADI sequence to a common north
     given a vector with the corresponding parallactic angles for each frame. By
@@ -331,10 +322,14 @@ def cube_derotate(array, angle_list, imlib='opencv', interpolation='lanczos4',
         number of frames).
     border_mode : str, optional
         See the documentation of the ``vip_hci.preproc.frame_rotate`` function.
+    mask_val: flt, opt
+        See the documentation of the ``vip_hci.preproc.frame_rotate`` function.
     edge_blend : str, optional
         See the documentation of the ``vip_hci.preproc.frame_rotate`` function.
     interp_zeros : str, optional
         See the documentation of the ``vip_hci.preproc.frame_rotate`` function.
+    ker: int, optional
+        See the documentation of the ``vip_hci.preproc.frame_rotate`` function.
         
     Returns
     -------
@@ -357,24 +352,22 @@ def cube_derotate(array, angle_list, imlib='opencv', interpolation='lanczos4',
                                         border_mode=border_mode, 
                                         mask_val=mask_val, 
                                         edge_blend=edge_blend,
-                                        interp_zeros=interp_zeros)
+                                        interp_zeros=interp_zeros, ker=ker)
     elif nproc > 1:
-        global data_array
-        data_array = array
 
-        res = pool_map(nproc, _frame_rotate_mp, iterable(range(n_frames)),
-                       angle_list, imlib, interpolation, cxy, border_mode, 
-                       mask_val, edge_blend, interp_zeros)
+        res = pool_map(nproc, _frame_rotate_mp, iterable(array), 
+                       iterable(-angle_list), imlib, interpolation, cxy, 
+                       border_mode, mask_val, edge_blend, interp_zeros, ker)
         array_der = np.array(res)
 
     return array_der
 
 
-def _frame_rotate_mp(num_fr, angle_list, imlib, interpolation, cxy,
-                     border_mode, mask_val, edge_blend, interp_zeros):
-    framerot = frame_rotate(data_array[num_fr], -angle_list[num_fr], imlib,
-                            interpolation, cxy, border_mode, mask_val, 
-                            edge_blend, interp_zeros)
+def _frame_rotate_mp(frame, angle, imlib, interpolation, cxy, border_mode, 
+                     mask_val, edge_blend, interp_zeros, ker):
+    framerot = frame_rotate(frame, angle, imlib, interpolation, cxy, 
+                            border_mode, mask_val, edge_blend, interp_zeros, 
+                            ker)
     return framerot
 
 
