@@ -4,7 +4,7 @@
 Module containing functions for cubes frame registration.
 """
 
-__author__ = 'Carlos Alberto Gomez Gonzalez, V. Christiaens, G. Ruane'
+__author__ = 'C. A. Gomez Gonzalez, V. Christiaens, G. Ruane, R. Farkas'
 __all__ = ['frame_shift',
            'cube_shift',
            'frame_center_radon',
@@ -49,7 +49,7 @@ from ..var import (get_square, frame_center, get_annulus_segments,
 from ..preproc import cube_crop_frames
 
 
-def frame_shift(array, shift_y, shift_x, imlib='opencv',
+def frame_shift(array, shift_y, shift_x, imlib='vip-fft',
                 interpolation='lanczos4', border_mode='reflect'):
     """ Shifts a 2D array by shift_y, shift_x. Boundaries are filled with zeros.
 
@@ -59,12 +59,13 @@ def frame_shift(array, shift_y, shift_x, imlib='opencv',
         Input 2d array.
     shift_y, shift_x: float
         Shifts in y and x directions.
-    imlib : {'opencv', 'ndimage-fourier', 'ndimage-interp'}, string optional
+    imlib : {'opencv', 'ndimage-fourier', 'ndimage-interp', 'vip-fft'}, str opt
         Library or method used for performing the image shift.
-        'ndimage-fourier', does a fourier shift operation and preserves better
-        the pixel values (therefore the flux and photometry). Interpolation
-        based shift ('opencv' and 'ndimage-interp') is faster than the fourier
-        shift. 'opencv' is recommended when speed is critical.
+        'ndimage-fourier' or 'vip-fft': does a fourier shift operation and 
+        preserves better the pixel values - therefore the flux and photometry
+        (wrapper of scipy.ndimage.fourier_shift). Interpolation-based shift 
+        ('opencv' and 'ndimage-interp') is faster but less accurate than the 
+        fourier shift. 'opencv' is recommended when speed is critical.
     interpolation : str, optional
         Only used in case of imlib is set to 'opencv' or 'ndimage-interp'
         (Scipy.ndimage), where the images are shifted via interpolation.
@@ -94,7 +95,7 @@ def frame_shift(array, shift_y, shift_x, imlib='opencv',
     check_array(array, dim=2)
     image = array.copy()
 
-    if imlib == 'ndimage-fourier':
+    if imlib == 'ndimage-fourier' or imlib == 'vip-fft':
         shift_val = (shift_y, shift_x)
         array_shifted = fourier_shift(np.fft.fftn(image), shift_val)
         array_shifted = np.fft.ifftn(array_shifted)
@@ -159,14 +160,14 @@ def frame_shift(array, shift_y, shift_x, imlib='opencv',
         M = np.float32([[1, 0, shift_x], [0, 1, shift_y]])
         array_shifted = cv2.warpAffine(image, M, (x, y), flags=intp,
                                        borderMode=bormo)
-
+        
     else:
         raise ValueError('Image transformation library not recognized')
 
     return array_shifted
 
 
-def cube_shift(cube, shift_y, shift_x, imlib='opencv',
+def cube_shift(cube, shift_y, shift_x, imlib='vip-fft', 
                interpolation='lanczos4'):
     """ Shifts the X-Y coordinates of a cube or 3D array by x and y values.
 
@@ -204,7 +205,7 @@ def cube_shift(cube, shift_y, shift_x, imlib='opencv',
 
 
 def frame_center_satspots(array, xy, subi_size=19, sigfactor=6, shift=False,
-                          imlib='opencv', interpolation='lanczos4',
+                          imlib='vip-fft', interpolation='lanczos4',
                           fit_type='moff', debug=False, verbose=True):
     """ Finds the center of a frame with waffle/satellite spots (e.g. for
     VLT/SPHERE). The method used to determine the center is by centroiding the
@@ -723,7 +724,7 @@ def _radon_costf(frame, cent, radint, coords, satspots_cfg=None):
     return costf
 
 
-def cube_recenter_radon(array, full_output=False, verbose=True, imlib='opencv',
+def cube_recenter_radon(array, full_output=False, verbose=True, imlib='vip-fft',
                         interpolation='lanczos4', **kwargs):
     """ Recenters a cube looping through its frames and calling the
     ``frame_center_radon`` function.
@@ -793,7 +794,7 @@ def cube_recenter_radon(array, full_output=False, verbose=True, imlib='opencv',
 
 def cube_recenter_dft_upsampling(array, center_fr1=None, negative=False,
                                  fwhm=4, subi_size=None, upsample_factor=100,
-                                 imlib='opencv', interpolation='lanczos4',
+                                 imlib='vip-fft', interpolation='lanczos4',
                                  mask=None, full_output=False, verbose=True, 
                                  nproc=1, save_shifts=False, debug=False, 
                                  plot=True):
@@ -1007,7 +1008,7 @@ def _shift_dft(array_rec, array, frnum, upsample_factor, mask, interpolation,
 
 
 def cube_recenter_2dfit(array, xy=None, fwhm=4, subi_size=5, model='gauss',
-                        nproc=1, imlib='opencv', interpolation='lanczos4',
+                        nproc=1, imlib='vip-fft', interpolation='lanczos4',
                         offset=None, negative=False, threshold=False, 
                         sigfactor=2, fix_neg=False, params_2g=None, 
                         save_shifts=False, full_output=False, verbose=True, 
@@ -1341,7 +1342,7 @@ def cube_recenter_via_speckles(cube_sci, cube_ref=None, alignment_iter=5,
                                gammaval=1, min_spat_freq=0.5, max_spat_freq=3,
                                fwhm=4, debug=False, recenter_median=False,
                                fit_type='gaus', negative=True, crop=True,
-                               subframesize=21, mask=None, imlib='opencv', 
+                               subframesize=21, mask=None, imlib='vip-fft', 
                                interpolation='lanczos4', plot=True, 
                                full_output=False):
     """ Registers frames based on the median speckle pattern. Optionally centers
