@@ -27,7 +27,7 @@ from ..var import frame_center, get_square
 from .subsampling import cube_collapse
 
 
-def cube_px_resampling(array, scale, imlib='opencv', interpolation='lanczos4',
+def cube_px_resampling(array, scale, imlib='vip-fft', interpolation='lanczos4',
                        verbose=True):
     """
     Resample the frames of a cube with a single scale factor. Can deal with NaN 
@@ -75,7 +75,7 @@ def cube_px_resampling(array, scale, imlib='opencv', interpolation='lanczos4',
     return array_resc
 
 
-def frame_px_resampling(array, scale, imlib='opencv', interpolation='lanczos4',
+def frame_px_resampling(array, scale, imlib='vip-fft', interpolation='lanczos4',
                         verbose=False):
     """
     Resample the pixels of a frame wrt to the center, changing the frame size.
@@ -228,7 +228,7 @@ def frame_px_resampling(array, scale, imlib='opencv', interpolation='lanczos4',
 
 
 def cube_rescaling_wavelengths(cube, scal_list, full_output=True, inverse=False,
-                               y_in=None, x_in=None, imlib='opencv',
+                               y_in=None, x_in=None, imlib='vip-fft',
                                interpolation='lanczos4', collapse='median',
                                pad_mode='reflect'):
     """
@@ -387,7 +387,7 @@ def _scale_func(output_coords, ref_xy=0, scaling=1.0, scale_y=None,
             ref_x + (output_coords[1] - ref_x) / scale_x)
 
 
-def frame_rescaling(array, ref_xy=None, scale=1.0, imlib='opencv',
+def frame_rescaling(array, ref_xy=None, scale=1.0, imlib='vip-fft',
                     interpolation='lanczos4', scale_y=None, scale_x=None):
     """
     Rescale a frame by a factor wrt a reference point.
@@ -544,7 +544,7 @@ def frame_rescaling(array, ref_xy=None, scale=1.0, imlib='opencv',
     return array_out
 
 
-def _cube_resc_wave(array, scaling_list, ref_xy=None, imlib='opencv',
+def _cube_resc_wave(array, scaling_list, ref_xy=None, imlib='vip-fft',
                     interpolation='lanczos4', scaling_y=None, scaling_x=None):
     """
     Rescale a cube by factors from ``scaling_list`` wrt a position.
@@ -626,7 +626,8 @@ def check_scal_vector(scal_vec):
 def find_scal_vector(cube, lbdas, fluxes, mask=None, nfp=2, fm="stddev", 
                      simplex_options=None, debug=False, **kwargs):
     """
-    Find the optimal scaling factor for the channels of an IFS cube (or .
+    Find the optimal scaling factor for the channels of an IFS cube (or of 
+    dual-band pairs of images).
 
     The algorithm finds the optimal scaling factor that minimizes residuals in
     the rescaled frames. It takes the inverse of the wavelength vector as a 
@@ -661,7 +662,9 @@ def find_scal_vector(cube, lbdas, fluxes, mask=None, nfp=2, fm="stddev",
     scal_vec: numpy ndarray, 1d
         Vector containing the scaling factors (after correction to comply with
         the condition >= 1).
-
+    if nfp==2, also returns:
+    flux_vec: numpy ndarray, 1d
+        Vector containing the associated flux factors.
     """
 
     scal_vec_ini = lbdas[-1]/lbdas
